===========
Django HOPE
===========

.. start-badges



|codacygrade|
|codacycoverage|
|version|
|wheel|


.. |codacygrade| image:: https://api.codacy.com/project/badge/Grade/2909ec710ee84c438bf9dd191544c105
    :target: https://www.codacy.com/app/CSTB/django-hope/dashboard
    :alt: Codacy Code Quality Status

.. |codacycoverage| image:: https://api.codacy.com/project/badge/Coverage/2909ec710ee84c438bf9dd191544c105
    :target: https://www.codacy.com/app/CSTB/django-hope/dashboard
    :alt: Codacy Code Coverage

.. |version| image:: https://img.shields.io/pypi/v/django-hope.svg?style=flat
    :target: https://pypi.org/project/django-hope/
    :alt: PyPI Package latest release

.. |wheel| image:: https://img.shields.io/pypi/wheel/django-hope.svg?style=flat
    :target: https://pypi.org/project/django-hope/
    :alt: PyPI Wheel



.. end-badges

Django application to implement the HOPE library.

License
=======

Software licensed under `ISC`_ license.

.. _ISC: https://www.isc.org/downloads/software-support-policy/isc-license/

Installation
============

::

    pip install django-hope

Documentation
=============

`On ReadTheDocs`_

.. _`On ReadTheDocs`: http://django-hope.readthedocs.io/

Development
===========

To run all the tests: ``tox``
